=== modified file 'bzrlib/msgeditor.py'
--- bzrlib/msgeditor.py	2007-08-31 05:32:00 +0000
+++ bzrlib/msgeditor.py	2007-09-06 11:59:59 +0000
@@ -102,8 +102,8 @@
 
     if not start_message is None:
         start_message = start_message.encode(bzrlib.user_encoding)
-    return edit_commit_message_encoded(infotext.encode(bzrlib.user_encoding),
-                                       ignoreline, start_message)
+    infotext = infotext.encode(bzrlib.user_encoding, 'replace')
+    return edit_commit_message_encoded(infotext, ignoreline, start_message)
 
 
 def edit_commit_message_encoded(infotext, ignoreline=DEFAULT_IGNORE_LINE,

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2007-09-05 08:18:57 +0000
+++ bzrlib/tests/__init__.py	2007-09-06 11:59:59 +0000
@@ -72,7 +72,6 @@
     pass
 from bzrlib.merge import merge_inner
 import bzrlib.merge3
-import bzrlib.osutils
 import bzrlib.plugin
 from bzrlib.revision import common_ancestor
 import bzrlib.store
@@ -1148,6 +1147,7 @@
             'BZR_HOME': None, # Don't inherit BZR_HOME to all the tests.
             'HOME': os.getcwd(),
             'APPDATA': None,  # bzr now use Win32 API and don't rely on APPDATA
+            'BZR_EDITOR': None, # test_msgeditor manipulate with this variable
             'BZR_EMAIL': None,
             'BZREMAIL': None, # may still be present in the environment
             'EMAIL': None,
@@ -1320,7 +1320,9 @@
             working_dir):
         """Run bazaar command line, splitting up a string command line."""
         if isinstance(args, basestring):
-            args = list(shlex.split(args))
+            # shlex don't understand unicode strings,
+            # so args should be plain string (bialix 20070906)
+            args = list(shlex.split(str(args)))
         return self._run_bzr_core(args, retcode=retcode,
                 encoding=encoding, stdin=stdin, working_dir=working_dir,
                 )
@@ -1878,7 +1880,7 @@
     def _make_test_root(self):
         if TestCaseWithMemoryTransport.TEST_ROOT is not None:
             return
-        root = tempfile.mkdtemp(prefix='testbzr-', suffix='.tmp')
+        root = osutils.mkdtemp(prefix='testbzr-', suffix='.tmp')
         TestCaseWithMemoryTransport.TEST_ROOT = root
         
         # make a fake bzr directory there to prevent any tests propagating
@@ -1994,7 +1996,7 @@
         name and then create two subdirs - test and home under it.
         """
         # create a directory within the top level test directory
-        candidate_dir = tempfile.mkdtemp(dir=self.TEST_ROOT)
+        candidate_dir = osutils.mkdtemp(dir=self.TEST_ROOT)
         # now create test and home directories within this dir
         self.test_base_dir = candidate_dir
         self.test_home_dir = self.test_base_dir + '/home'
@@ -2670,3 +2672,18 @@
         else:
             return uni_val, str_val
     return None, None
+
+
+def probe_bad_non_ascii_in_user_encoding():
+    """Try to find [bad] character with code [128..255]
+    that cannot be decoded to unicode in user_encoding.
+    Return None if all non-ascii characters is valid
+    for current user_encoding.
+    """
+    for i in xrange(128, 256):
+        char = chr(i)
+        try:
+            char.decode(bzrlib.user_encoding)
+        except UnicodeDecodeError:
+            return char
+    return None

=== modified file 'bzrlib/tests/blackbox/test_commit.py'
--- bzrlib/tests/blackbox/test_commit.py	2007-09-05 00:43:01 +0000
+++ bzrlib/tests/blackbox/test_commit.py	2007-09-06 11:59:59 +0000
@@ -18,11 +18,17 @@
 """Tests for the commit CLI of bzr."""
 
 import os
+import sys
 
 from bzrlib import (
     ignores,
+    osutils,
     )
 from bzrlib.bzrdir import BzrDir
+from bzrlib.tests import (
+    probe_bad_non_ascii_in_user_encoding,
+    TestSkipped,
+    )
 from bzrlib.tests.blackbox import ExternalBase
 
 
@@ -154,7 +160,7 @@
         a_tree.commit(message='Initial message')
 
         b_tree = a_tree.branch.create_checkout('b')
-        expected = "%s/" % (os.path.abspath('a'), )
+        expected = "%s/" % (osutils.abspath('a'), )
         out, err = self.run_bzr('commit -m blah --unchanged', working_dir='b')
         self.assertEqual(err, 'Committing revision 2 to "%s".\n'
                          'Committed revision 2.\n' % expected)
@@ -212,7 +218,7 @@
         os.chdir('this')
         out,err = self.run_bzr('commit -m added')
         self.assertEqual('', out)
-        expected = '%s/' % (os.getcwd(), )
+        expected = '%s/' % (osutils.getcwd(), )
         self.assertEqualDiff(
             'Committing revision 2 to "%s".\n'
             'modified filetomodify\n'
@@ -237,8 +243,17 @@
         tree = self.make_branch_and_tree('.')
         self.build_tree_contents([('foo.c', 'int main() {}')])
         tree.add('foo.c')
-        out,err = self.run_bzr_subprocess('commit -m "\xff"', retcode=1,
-                                                    env_changes={'LANG': 'C'})
+        # LANG env variable has no effect on Windows
+        # but some characters anyway cannot be represented
+        # in default user encoding
+        char = '\xff'
+        if sys.platform == 'win32':
+            char = probe_bad_non_ascii_in_user_encoding()
+            if char is None:
+                raise TestSkipped('cannot find suitable character')
+        out,err = self.run_bzr_subprocess('commit -m "%s"' % char,
+                                          retcode=1,
+                                          env_changes={'LANG': 'C'})
         self.assertContainsRe(err, r'bzrlib.errors.BzrError: Parameter.*is '
                                     'unsupported by the current encoding.')
 

=== modified file 'bzrlib/tests/blackbox/test_info.py'
--- bzrlib/tests/blackbox/test_info.py	2007-08-23 14:10:48 +0000
+++ bzrlib/tests/blackbox/test_info.py	2007-09-06 11:59:59 +0000
@@ -23,6 +23,7 @@
 import bzrlib
 from bzrlib import (
     bzrdir,
+    errors,
     osutils,
     repository,
     urlutils,

=== modified file 'bzrlib/tests/blackbox/test_remove.py'
--- bzrlib/tests/blackbox/test_remove.py	2007-08-04 20:36:29 +0000
+++ bzrlib/tests/blackbox/test_remove.py	2007-09-06 11:59:59 +0000
@@ -16,7 +16,9 @@
 
 
 import os
+import sys
 
+from bzrlib.tests import TestSkipped
 from bzrlib.tests.blackbox import ExternalBase
 from bzrlib.workingtree import WorkingTree
 from bzrlib import osutils
@@ -122,6 +124,8 @@
         self.run_bzr_remove_changed_files(['modified:[.\s]*a[.\s]*b/c'], files)
 
     def test_remove_changed_files_from_child_dir(self):
+        if sys.platform == 'win32':
+            raise TestSkipped("Windows unable to remove '.' directory")
         tree = self._make_add_and_assert_tree(files)
         self.run_bzr("commit -m 'added files'")
         self.changeFile(a)

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2007-08-31 05:32:00 +0000
+++ bzrlib/tests/test_msgeditor.py	2007-09-06 11:59:59 +0000
@@ -20,6 +20,7 @@
 import os
 import sys
 
+import bzrlib
 from bzrlib import (
     errors,
     msgeditor,
@@ -31,7 +32,11 @@
     make_commit_message_template_encoded,
     edit_commit_message_encoded
 )
-from bzrlib.tests import TestCaseWithTransport, TestSkipped
+from bzrlib.tests import (
+    probe_bad_non_ascii_in_user_encoding,
+    TestCaseWithTransport,
+    TestSkipped,
+    )
 from bzrlib.trace import mutter
 
 class MsgEditorTest(TestCaseWithTransport):
@@ -90,18 +95,6 @@
   hell\u00d8
 """.encode('utf8') in template)
 
-    def setUp(self):
-        super(MsgEditorTest, self).setUp()
-        self._bzr_editor = os.environ.get('BZR_EDITOR', None)
-
-    def tearDown(self):
-        if self._bzr_editor is not None:
-            os.environ['BZR_EDITOR'] = self._bzr_editor
-        else:
-            if os.environ.get('BZR_EDITOR', None) is not None:
-                del os.environ['BZR_EDITOR']
-        super(MsgEditorTest, self).tearDown()
-
     def test_run_editor(self):
         if sys.platform == "win32":
             f = file('fed.bat', 'w')
@@ -162,6 +155,10 @@
         self.assertEqual('test message from fed\n',
                          msgeditor.edit_commit_message(''))
 
+        mutter('edit_commit_message with ascii string infotext')
+        self.assertEqual('test message from fed\n',
+                         msgeditor.edit_commit_message('spam'))
+
         mutter('edit_commit_message with unicode infotext')
         self.assertEqual('test message from fed\n',
                          msgeditor.edit_commit_message(u'\u1234'))
@@ -256,7 +253,16 @@
     def test_unsupported_encoding_commit_message(self):
         old_env = osutils.set_or_unset_env('LANG', 'C')
         try:
-            self.make_fake_editor(message='\xff')
+            # LANG env variable has no effect on Windows
+            # but some characters anyway cannot be represented
+            # in default user encoding
+            char = '\xff'
+            if sys.platform == 'win32':
+                char = probe_bad_non_ascii_in_user_encoding()
+                if char is None:
+                    raise TestSkipped('cannot find suitable character')
+
+            self.make_fake_editor(message=char)
 
             working_tree = self.make_uncommitted_tree()
             self.assertRaises(errors.BadCommitMessageEncoding,

=== modified file 'bzrlib/tests/test_plugins.py'
--- bzrlib/tests/test_plugins.py	2007-08-29 01:16:53 +0000
+++ bzrlib/tests/test_plugins.py	2007-09-06 11:59:59 +0000
@@ -32,7 +32,7 @@
 import bzrlib.help
 from bzrlib.symbol_versioning import zero_ninetyone
 from bzrlib.tests import TestCase, TestCaseInTempDir
-from bzrlib.osutils import pathjoin, abspath
+from bzrlib.osutils import pathjoin, abspath, normpath
 
 
 PLUGIN_TEXT = """\
@@ -241,7 +241,7 @@
         plugins = bzrlib.plugin.plugins()
         plugin = plugins['plugin']
         plugin_path = self.test_dir + '/plugin.py'
-        self.assertEqual(plugin_path, plugin.path())
+        self.assertEqual(plugin_path, normpath(plugin.path()))
 
     def test_no_test_suite_gives_None_for_test_suite(self):
         self.setup_plugin()

=== modified file 'bzrlib/tests/test_transport.py'
--- bzrlib/tests/test_transport.py	2007-08-19 20:38:10 +0000
+++ bzrlib/tests/test_transport.py	2007-09-06 11:59:59 +0000
@@ -23,6 +23,7 @@
 import bzrlib
 from bzrlib import (
     errors,
+    osutils,
     urlutils,
     )
 from bzrlib.errors import (ConnectionError,
@@ -572,26 +573,26 @@
 class TestLocalTransports(TestCase):
 
     def test_get_transport_from_abspath(self):
-        here = os.path.abspath('.')
+        here = osutils.abspath('.')
         t = get_transport(here)
         self.assertIsInstance(t, LocalTransport)
         self.assertEquals(t.base, urlutils.local_path_to_url(here) + '/')
 
     def test_get_transport_from_relpath(self):
-        here = os.path.abspath('.')
+        here = osutils.abspath('.')
         t = get_transport('.')
         self.assertIsInstance(t, LocalTransport)
         self.assertEquals(t.base, urlutils.local_path_to_url('.') + '/')
 
     def test_get_transport_from_local_url(self):
-        here = os.path.abspath('.')
+        here = osutils.abspath('.')
         here_url = urlutils.local_path_to_url(here) + '/'
         t = get_transport(here_url)
         self.assertIsInstance(t, LocalTransport)
         self.assertEquals(t.base, here_url)
 
     def test_local_abspath(self):
-        here = os.path.abspath('.')
+        here = osutils.abspath('.')
         t = get_transport(here)
         self.assertEquals(t.local_abspath(''), here)
 

